@@ -44,7 +44,7 @@ Change::Private::Private(const Private &other)
 
 ChangePtr Change::Private::fromJSON(const QVariantMap &map)
 {
-    if (!map.contains(QLatin1String("kind")) || map[QStringLiteral("kind")].toString() != QLatin1String("drive#change")) {
+    if (!map.contains(QLatin1StringView("kind")) || map[QStringLiteral("kind")].toString() != QLatin1StringView("drive#change")) {
         return ChangePtr();
     }
 
@@ -134,11 +134,11 @@ ChangesList Change::fromJSONFeed(const QByteArray &jsonData, FeedData &feedData)
 
     const QVariant data = document.toVariant();
     const QVariantMap map = data.toMap();
-    if (!map.contains(QLatin1String("kind")) || map[QStringLiteral("kind")].toString() != QLatin1String("drive#changeList")) {
+    if (!map.contains(QLatin1StringView("kind")) || map[QStringLiteral("kind")].toString() != QLatin1StringView("drive#changeList")) {
         return ChangesList();
     }
 
-    if (map.contains(QLatin1String("nextLink"))) {
+    if (map.contains(QLatin1StringView("nextLink"))) {
         feedData.nextPageUrl = map[QStringLiteral("nextLink")].toUrl();
     }
 
