@@ -3,4 +3,4 @@ from .enum import Enum
 from .ref import Ref
 from .object import Object
 
-__all__ = ['QVector', 'QDate', 'QString', 'Boolean', 'Integer', 'Enum', 'Ref', 'Object']
\ No newline at end of file
+__all__ = ['QList', 'QDate', 'QString', 'Boolean', 'Integer', 'Enum', 'Ref', 'Object']
\ No newline at end of file
